==> spring-boot-3.20.7-source-release.zip: spring-boot-3.20.7/components-starter/camel-openapi-java-starter/src/test/java/org/apache/camel/openapi/SpringRestOpenApiReaderModelApiSecurityTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.openapi;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.apache.camel.CamelContext;
import org.apache.camel.impl.engine.DefaultClassResolver;
import org.apache.camel.model.ModelCamelContext;
import org.apache.camel.spring.boot.CamelAutoConfiguration;
import org.apache.camel.test.spring.junit5.CamelSpringBootTest;

import org.junit.jupiter.api.Test;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.DirtiesContext;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

import io.apicurio.datamodels.Library;
import io.apicurio.datamodels.openapi.models.OasDocument;

@DirtiesContext(classMode = DirtiesContext.ClassMode.AFTER_EACH_TEST_METHOD)
@CamelSpringBootTest
@SpringBootTest(
		classes = {
				CamelAutoConfiguration.class,
				SpringRestOpenApiReaderModelApiSecurityTest.class,
				DummyUserService.class,
				DummyRestConsumerFactory.class
		},
		properties = {"camel.springboot.routes-include-pattern=file:src/test/resources/org/apache/camel/openapi/SpringRestOpenApiReaderModelApiSecurityTest.xml"}
)
public class SpringRestOpenApiReaderModelApiSecurityTest {

	private final Logger log = LoggerFactory.getLogger(getClass());

	@Autowired
	CamelContext context;

	@Test
	public void testReaderRead() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setTitle("Camel User store");
		config.setLicense("Apache 2.0");
		config.setLicenseUrl("http://www.apache.org/licenses/LICENSE-2.0.html");
		config.setVersion("2.0");
		RestOpenApiReader reader = new RestOpenApiReader();

		OasDocument openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		ObjectMapper mapper = new ObjectMapper();
		mapper.enable(SerializationFeature.INDENT_OUTPUT);
		mapper.setSerializationInclusion(JsonInclude.Include.NON_NULL);
		Object dump = Library.writeNode(openApi);
		String json = mapper.writeValueAsString(dump);

		log.info(json);

		assertTrue(json.contains("\"securityDefinitions\" : {"));
		assertTrue(json.contains("\"type\" : \"oauth2\""));
		assertTrue(json.contains("\"authorizationUrl\" : \"http://petstore.swagger.io/oauth/dialog\""));
		assertTrue(json.contains("\"flow\" : \"implicit\""));
		assertTrue(json.contains("\"type\" : \"apiKey\","));
		assertTrue(json.contains("\"in\" : \"header\""));
		assertTrue(json.contains("\"host\" : \"localhost:8080\""));
		assertTrue(json.contains("\"security\" : [ {"));
		assertTrue(json.contains("\"petstore_auth\" : [ \"write:pets\", \"read:pets\" ]"));
		assertTrue(json.contains("\"api_key\" : [ ]"));
		assertTrue(json.contains("\"description\" : \"The user returned\""));
		assertTrue(json.contains("\"$ref\" : \"#/definitions/User\""));
		assertTrue(json.contains("\"x-className\""));
		assertTrue(json.contains("\"format\" : \"org.apache.camel.openapi.User\""));
		assertTrue(json.contains("\"type\" : \"string\""));
		assertTrue(json.contains("\"format\" : \"date\""));
		assertFalse(json.contains("\"enum\""));

		context.stop();
	}

	@Test
	public void testReaderReadV3() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setTitle("Camel User store");
		config.setLicense("Apache 2.0");
		config.setLicenseUrl("http://www.apache.org/licenses/LICENSE-2.0.html");
		RestOpenApiReader reader = new RestOpenApiReader();

		OasDocument openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		ObjectMapper mapper = new ObjectMapper();
		mapper.enable(SerializationFeature.INDENT_OUTPUT);
		mapper.setSerializationInclusion(JsonInclude.Include.NON_NULL);
		Object dump = Library.writeNode(openApi);
		String json = mapper.writeValueAsString(dump);

		log.info(json);

		assertTrue(json.contains("\"securitySchemes\" : {"));
		assertTrue(json.contains("\"type\" : \"oauth2\""));
		assertTrue(json.contains("\"authorizationUrl\" : \"http://petstore.swagger.io/oauth/dialog\""));
		assertTrue(json.contains("\"flows\" : {"));
		assertTrue(json.contains("\"implicit\" : {"));
		assertTrue(json.contains("\"type\" : \"apiKey\","));
		assertTrue(json.contains("\"in\" : \"header\""));
		assertTrue(json.contains("\"url\" : \"http://localhost:8080/api\""));
		assertTrue(json.contains("\"security\" : [ {"));
		assertTrue(json.contains("\"petstore_auth\" : [ \"write:pets\", \"read:pets\" ]"));
		assertTrue(json.contains("\"api_key\" : [ ]"));
		assertTrue(json.contains("\"description\" : \"The user returned\""));
		assertTrue(json.contains("\"$ref\" : \"#/components/schemas/User\""));
		assertTrue(json.contains("\"x-className\""));
		assertTrue(json.contains("\"format\" : \"org.apache.camel.openapi.User\""));
		assertTrue(json.contains("\"type\" : \"string\""));
		assertTrue(json.contains("\"format\" : \"date\""));
		assertFalse(json.contains("\"enum\""));

		context.stop();
	}
}

==> spring-boot-4.0.1-source-release.zip: spring-boot-4.0.1/components-starter/camel-openapi-java-starter/src/test/java/org/apache/camel/openapi/SpringRestOpenApiReaderModelApiSecurityTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.openapi;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.apache.camel.CamelContext;
import org.apache.camel.impl.engine.DefaultClassResolver;
import org.apache.camel.model.ModelCamelContext;
import org.apache.camel.spring.boot.CamelAutoConfiguration;
import org.apache.camel.test.spring.junit5.CamelSpringBootTest;

import org.junit.jupiter.api.Test;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.annotation.DirtiesContext;


import io.swagger.v3.core.util.Json;
import io.swagger.v3.oas.models.OpenAPI;

@DirtiesContext(classMode = DirtiesContext.ClassMode.AFTER_EACH_TEST_METHOD)
@CamelSpringBootTest
@SpringBootTest(
		classes = {
				CamelAutoConfiguration.class,
				SpringRestOpenApiReaderModelApiSecurityTest.class,
				DummyUserService.class,
				DummyRestConsumerFactory.class
		},
		properties = {"camel.springboot.routes-include-pattern=file:src/test/resources/org/apache/camel/openapi/SpringRestOpenApiReaderModelApiSecurityTest.xml"}
)
public class SpringRestOpenApiReaderModelApiSecurityTest {

	private final Logger log = LoggerFactory.getLogger(getClass());

	@Autowired
	CamelContext context;

	@Test
	public void testReaderRead() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setTitle("Camel User store");
		config.setLicense("Apache 2.0");
		config.setLicenseUrl("http://www.apache.org/licenses/LICENSE-2.0.html");
		config.setVersion("2.0");
		RestOpenApiReader reader = new RestOpenApiReader();

		OpenAPI openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		String json = RestOpenApiSupport.getJsonFromOpenAPI(openApi, config);

		log.info(json);

		assertTrue(json.contains("\"securityDefinitions\" : {"));
		assertTrue(json.contains("\"type\" : \"oauth2\""));
		assertTrue(json.contains("\"authorizationUrl\" : \"http://petstore.swagger.io/oauth/dialog\""));
		assertTrue(json.contains("\"flow\" : \"implicit\""));
		assertTrue(json.contains("\"type\" : \"apiKey\","));
		assertTrue(json.contains("\"in\" : \"header\""));
		assertTrue(json.contains("\"host\" : \"localhost:8080\""));
		assertTrue(json.contains("\"security\" : [ {"));
		assertTrue(json.contains("\"petstore_auth\" : [ \"write:pets\", \"read:pets\" ]"));
		assertTrue(json.contains("\"api_key\" : [ ]"));
		assertTrue(json.contains("\"description\" : \"The user returned\""));
		assertTrue(json.contains("\"$ref\" : \"#/definitions/User\""));
		assertTrue(json.contains("\"x-className\""));
		assertTrue(json.contains("\"format\" : \"org.apache.camel.openapi.User\""));
		assertTrue(json.contains("\"type\" : \"string\""));
		assertTrue(json.contains("\"format\" : \"date\""));
		assertFalse(json.contains("\"enum\""));

		context.stop();
	}

	@Test
	public void testReaderReadV3() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setTitle("Camel User store");
		config.setLicense("Apache 2.0");
		config.setLicenseUrl("http://www.apache.org/licenses/LICENSE-2.0.html");
		RestOpenApiReader reader = new RestOpenApiReader();

		OpenAPI openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		String json = Json.pretty(openApi);

		log.info(json);

		assertTrue(json.contains("\"securitySchemes\" : {"));
		assertTrue(json.contains("\"type\" : \"oauth2\""));
		assertTrue(json.contains("\"authorizationUrl\" : \"http://petstore.swagger.io/oauth/dialog\""));
		assertTrue(json.contains("\"flows\" : {"));
		assertTrue(json.contains("\"implicit\" : {"));
		assertTrue(json.contains("\"type\" : \"apiKey\","));
		assertTrue(json.contains("\"in\" : \"header\""));
		assertTrue(json.contains("\"url\" : \"http://localhost:8080/api\""));
		assertTrue(json.contains("\"security\" : [ {"));
		assertTrue(json.contains("\"petstore_auth\" : [ \"write:pets\", \"read:pets\" ]"));
		assertTrue(json.contains("\"api_key\" : [ ]"));
		assertTrue(json.contains("\"description\" : \"The user returned\""));
		assertTrue(json.contains("\"$ref\" : \"#/components/schemas/User\""));
		assertTrue(json.contains("\"x-className\""));
		assertTrue(json.contains("\"format\" : \"org.apache.camel.openapi.User\""));
		assertTrue(json.contains("\"type\" : \"string\""));
		assertTrue(json.contains("\"format\" : \"date\""));
		assertFalse(json.contains("\"enum\""));

		context.stop();
	}
}
